import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card"
import { Button } from "@/components/ui/button"
import Link from "next/link"
import { CheckCircle, XCircle } from "lucide-react"

// Types based on the provided JSON format
type QuizQuestion = {
  qid: string
  question: string
  correct_answer: string
  explanation: string
  image_url: string
  suggestion: string[]
}

type UserAnswer = {
  questionId: string
  answer: string | null
  isCorrect: boolean
}

type ResultsProps = {
  userAnswers: UserAnswer[]
  questions: QuizQuestion[]
  score: number
  totalScore: number
}

export default function Results({ userAnswers, questions, score, totalScore }: ResultsProps) {
  const correctAnswers = userAnswers.filter((answer) => answer.isCorrect).length
  const incorrectAnswers = userAnswers.length - correctAnswers
  const percentage = Math.round((correctAnswers / questions.length) * 100)

  const getResultClass = () => {
    if (percentage >= 80) return "text-route-green"
    if (percentage >= 50) return "text-route-yellow"
    return "text-route-red"
  }

  // Format the question text to handle newlines and options
  const formatQuestionText = (text: string) => {
    // Split the question from the options
    const parts = text.split("\n\n")
    if (parts.length > 1) {
      return parts[0]
    }
    return text
  }

  // Get the correct answer text
  const getCorrectAnswerText = (question: QuizQuestion) => {
    const correctAnswer = question.correct_answer.toLowerCase()

    // If it's a letter (a, b, c), find the corresponding suggestion
    if (correctAnswer.length === 1 && correctAnswer >= "a" && correctAnswer <= "z") {
      const index = correctAnswer.charCodeAt(0) - "a".charCodeAt(0)
      if (question.suggestion && question.suggestion[index]) {
        return question.suggestion[index]
      }
    }

    // Otherwise return the answer directly
    return correctAnswer
  }

  // Get the user's answer text
  const getUserAnswerText = (question: QuizQuestion, userAnswer: UserAnswer) => {
    if (!userAnswer.answer) return "Pas de réponse"
    return userAnswer.answer
  }

  return (
    <div className="container mx-auto px-4 py-8 max-w-4xl">
      <Card className="mb-8 route-card">
        <CardHeader className="text-center">
          <CardTitle className="text-2xl">Résultats</CardTitle>
        </CardHeader>
        <CardContent>
          <div className="text-center mb-6">
            <h2 className={`text-4xl font-bold mb-2 ${getResultClass()}`}>
              {score}/{totalScore}
            </h2>
            <p className="text-lg text-muted-foreground">
              Vous avez obtenu {correctAnswers} bonnes réponses sur {questions.length} questions
            </p>
          </div>

          <div className="grid grid-cols-2 gap-4 mb-6">
            <div className="bg-route-green/10 p-4 rounded-lg flex items-center gap-3">
              <CheckCircle className="h-6 w-6 text-route-green" />
              <div>
                <p className="font-medium">Bonnes réponses</p>
                <p className="text-2xl font-bold">{correctAnswers}</p>
              </div>
            </div>
            <div className="bg-route-red/10 p-4 rounded-lg flex items-center gap-3">
              <XCircle className="h-6 w-6 text-route-red" />
              <div>
                <p className="font-medium">Mauvaises réponses</p>
                <p className="text-2xl font-bold">{incorrectAnswers}</p>
              </div>
            </div>
          </div>

          <div className="flex justify-center mb-8">
            <Link href="/">
              <Button className="bg-route-blue hover:bg-route-blue/90">Retour à l'accueil</Button>
            </Link>
          </div>

          <h3 className="text-xl font-bold mb-4">Récapitulatif détaillé</h3>
          <div className="space-y-6">
            {questions.map((question, index) => {
              const userAnswer = userAnswers.find((a) => a.questionId === question.qid)
              const isCorrect = userAnswer?.isCorrect || false

              return (
                <div
                  key={question.qid}
                  className={`border rounded-lg p-4 ${isCorrect ? "route-card-success" : "route-card-danger"}`}
                >
                  <div className="flex items-start gap-3 mb-3">
                    {isCorrect ? (
                      <CheckCircle className="h-5 w-5 text-route-green mt-0.5 flex-shrink-0" />
                    ) : (
                      <XCircle className="h-5 w-5 text-route-red mt-0.5 flex-shrink-0" />
                    )}
                    <div>
                      <p className="font-medium mb-2">
                        Question {index + 1}: {formatQuestionText(question.question)}
                      </p>

                      {question.image_url && (
                        <div className="mb-3">
                          <img
                            src={question.image_url || "/placeholder.svg"}
                            alt="Question illustration"
                            className="max-h-40 object-contain rounded-md border border-gray-200"
                          />
                        </div>
                      )}

                      <div className="pl-0 space-y-2">
                        <div>
                          <p className="text-sm text-muted-foreground">Votre réponse:</p>
                          <p className={isCorrect ? "text-route-green" : "text-route-red"}>
                            {userAnswer ? getUserAnswerText(question, userAnswer) : "Pas de réponse"}
                          </p>
                        </div>
                        {!isCorrect && (
                          <div>
                            <p className="text-sm text-muted-foreground">Réponse correcte:</p>
                            <p className="text-route-green">{getCorrectAnswerText(question)}</p>
                          </div>
                        )}
                        {question.explanation && (
                          <div>
                            <p className="text-sm text-muted-foreground">Explication:</p>
                            <p className="text-gray-700">{question.explanation}</p>
                          </div>
                        )}
                      </div>
                    </div>
                  </div>
                </div>
              )
            })}
          </div>
        </CardContent>
      </Card>
    </div>
  )
}
